@@ -25,6 +25,16 @@ def deserialise(klass):
         return wrapper
     return decorator
 
+def deserialise_args(klass):
+    def decorator(funct):
+        @functools.wraps(funct)
+        def wrapper(*args, **kwargs):
+            body = request.args
+            deserialise_body = klass(body)
+            return funct(deserialise_body, *args, **kwargs)
+        return wrapper
+    return decorator
+
 def serialise():
     def decorator(funct):
         @functools.wraps(funct)
